from setuptools import setup

setup(
    name='easyGuiCover',
    packages=['easyGuiCover'],
    version='0.0.1',
    author='Luka',
    author_email='app6onpython@gmail.com',
    description='This is easy library to open explorer on top of other screens!',
    keywords=['easyGuiCover', 'Cover', 'easyguicover', 'easygui', 'gui', 'easy', 'Easygui', 'Gui', 'Easy', 'cover'],
    install_requires=[],
    classifiers=[
        'Programming Language :: Python :: 3.9'
    ]
)
